

set -ex



python -m pip check
echo "Test CLI usage:" && pytesseract -l eng eurotext.tif
echo "Test pytesseract library usage:" && python -c "from PIL import Image; import pytesseract; print(pytesseract.image_to_string(Image.open('eurotext.tif')))"
exit 0
